Get the compartment index for the specified compartment name.
Source:R/generic.R, R/compartments.R, R/campsis_model.R
get_compartment_index.RdGet the compartment index for the specified compartment name.

R/generic.R, R/compartments.R, R/campsis_model.R
get_compartment_index.RdGet the compartment index for the specified compartment name.