Get the name of the given parameter in the Campsis model.
Source:R/parameter.R
get_name_in_model.RdGet the name of the given parameter in the Campsis model.

R/parameter.R
get_name_in_model.RdGet the name of the given parameter in the Campsis model.