Has exact method allows to check the existence of a S4 method in Campsis based on its signature.
Source:R/json_interface.R
has_exact_method.RdHas exact method allows to check the existence of a S4 method in Campsis based on its signature.
Usage
has_exact_method(generic, signature, where = topenv(parent.frame()))